##############################################################################
##############################################################################
#
# Screens Personnalisés
# (screens pour les crédits, pour le menu rapide, pour l'accueil,
# nv menu des options, screen pause
#
##############################################################################
##############################################################################


##############################################################################
# Screens pour les crédits
#
#
#------------------------------------------------------------------------------------
# Screen général
screen credit(type,illu,description):
# type = l'écran est différent pour une image ou un fichier audio
# Illu = image qui sera affichée comme illustration (la photo, la couv de l'album, la représentation du bruitage)
# description = éléments pour la desciption (sous forme de tableau): auteur, nom de l'asset, licence, ...
    window:
        style "st_credit"
        xsize 300
        xpos 650
        ypos 45
        #text _("Crédits") style "time_titre" xalign 0.5 size 30
            
    # À gauche : on a soit une simple image, soit image + boutons si c'est du son, donc un screen spécial (audio_illu)
    if type == "audio":
        use audio_illu(illu)
    else:
        add illu anchor (0.5,0.5) ypos 300 xpos 300
        
    # les items sont différents si on décrit une image ou du son (chacun a son propre screen)
    # on garde une solution par défaut où on reproduit simplement la chaine de caractère passée en argument
    if type == "audio":
        use audio_description(description)
    elif type == "image":
        use image_description(description)
    else:
        vbox:
            xpos 635
            ypos 100
            xsize 330
            text description style "st_credit"
            
    use menu_rapide()
    
style st_credit:
    color "#ccc"
    
    
#-----------------------------------------------------------------------------
# Affichage de la pochette et des boutons pour jouer musiques et sons (pour les crédits)
#
# Définition d'un channel spécifique pour les extraits audio
init python:
    renpy.music.register_channel('extraits', mixer='sample', loop=False)

screen audio_illu(donnees):
    
    # Le volume de la musique et du mixer des extraits est enregistré dans une variable persistante, récupérée avant l'affichage des crédits :
    
    on "replace" action [Stop("extraits"),SetMixer("music",persistent.volume)]
    on "hide" action [Stop("extraits"),SetMixer("music",persistent.volume)]
    
    vbox:
        style_group "audioillu"
        xanchor 0.5
        ypos 100
        xpos 300
        add donnees['illu']
        null height 20
        textbutton _("Jouer") action [SetMixer("music",0.0),Play("extraits",donnees['morceau'])]
        null height 20
        textbutton _("Stop") action [Stop("extraits"),SetMixer("music",persistent.volume)]

# pour mettre tous les boutons à la même largeur
init -2 python:
    style.audioillu_button.size_group = "audioillu"        
        
        
#-----------------------------------------------------------------------------
# Affichage de la description des musiques / sons
#
screen audio_description(infos):
    
    $ licence = affich_licence(infos['licence'],infos['version'])
    
    vbox:
        xpos 635
        ypos 100
        xsize 330
        
        # Affichage du titre de la description en fonction de la langue
        if _preferences.language == None:
            $ lang = "fr"
        else:
            $ lang = _preferences.language
        $ types = {"musique": {"fr":"Musique","en":"Music"},"son":{"fr":"Effet sonore","en":"Sound effect"}}
        
        text "{b}" + types[infos['type']][lang] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[infos[titre]] [par!t] [infos[auteur]]" style "st_credit"
        null height 20
        if infos['type'] == "musique":
            text _("Album : ") + infos ['album'] style "st_credit"
        null height 20
        # On vérifie si le type de licence est défini, sinon on met Creative Commons par defaut (compatibilités avec vieilles versions)
        if "type_lic" not in infos.keys():
            $ type_lic = "Creative Commons"
        else:
            $ type_lic = infos['type_lic']
        if _preferences.language == None:
            $ credit_licence = "sous licence %s" % type_lic
        else:
            $ credit_licence = "under %s license" % type_lic
        text  "[credit_licence]" style "st_credit"
        text licence style "st_credit"
        null height 20
        $ ecouter = _("}Écouter sur")
        text "{a=[infos[lien]][ecouter!t] [infos[site]]{/a}" style "st_credit"

    
#-----------------------------------------------------------------------------
# Affichage de la description des images
# 
screen image_description(infos):
    
    $ licence = affich_licence(infos['licence'],infos['version'])
    
    vbox:
        xpos 635
        ypos 100
        xsize 330
        
        text "{b}" + infos['titre'] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[par!t] [infos[auteur]]" style "st_credit"
        if infos ['pseudo'] is not None:
            text "(" + infos ['pseudo'] + ")" style "st_credit"
        null height 20
        $ original = _("}original sur ")
        # On vérifie si le type de licence est défini, sinon on met Creative Commons par defaut (compatibilités avec vieilles versions)
        if "type_lic" not in infos.keys():
            $ type_lic = "Creative Commons"
        else:
            $ type_lic = infos['type_lic']
        if _preferences.language == None:
            $ souslicence = "{/a}\n\nsous licence %s" % type_lic
        else:
            $ souslicence = "{/a}\n\nunder %s license" % type_lic
        # On vérifie si un nom de site est défini, sinon on laisse Flickr par défaut (compatibilités avec vieilles versions)
        if "site" not in infos.keys():
            $ site = "Flickr"
        else:
            $ site = infos['site']
        text "{a=[infos[lien]][original!t][site][souslicence]"  style "st_credit"
        text licence style "st_credit"

##############################################################################
# Screens pour les pauses
#
screen ecran_pause():
    
    # On empêche d'interagir avec ce qui est affiché en dessous
    modal True
    
    # Le volume de la musique et du son ont été transmis à l'affichage du screen
    # on met les volumes de la musique et des sons à zéro quand on rentre dans le screen
    on "show" action [SetVariable('music', _preferences.get_volume('music')),SetVariable('son', _preferences.get_volume('sfx')), SetMixer("music",0.0),SetMixer("sfx",0.0)]
    
    # on le remet les volumes à leur niveau initial quand on sort du screen
    on "hide" action [SetMixer("music",music),SetMixer("sfx",son)]
    
    # on recouvre l'écran avec un voile gris
    add Solid("#000c")
    
    # on utilise un tooltip pour afficher la légende du bouton pause qui suit
    default tt = Tooltip("")
    text tt.value align(0.65,0.5)
    
    # on ajoute un signe de pause, qui sert de bouton
    imagebutton:
        auto "gui/pause/icone_pause_%s.png" align (0.5,0.5)
        focus_mask True
        action Hide("ecran_pause")
        hovered tt.Action(_("Reprendre")) 

        
##############################################################################
# Menu des options
#
# Ceci met le "menu des options" comme menu par défaut "clic droit / échap"
init python:
    _game_menu_screen = "menu_options"

screen menu_options:
    # Ecran qui s'affiche quand on clique droit ou qu'on y accède par l'accueil ou le menu rapide
       
    # Pour être sûr que tout autre menu est remplacé
    tag menu

    # Fond du menu jeu
    window:
        style "gm_root"

    # Boutons de navigation.
    frame:
        style_group "mg_nav"
        xalign 0.5
        yalign 0.5

        has vbox
        
        hbox:
            textbutton _(u"{font=gui/open-iconic.ttf}\uE0DA{/font}\nPreferences") action ShowMenu("preferences")
            textbutton _(u"{font=gui/open-iconic.ttf}\uE003{/font}\nReturn") action Return()
        hbox:
            textbutton _(u"{font=gui/open-iconic.ttf}\uE021{/font}\nLoad Game") action ShowMenu("load")
            textbutton _(u"{font=gui/open-iconic.ttf}\uE078{/font}\nMain Menu") action MainMenu()
        hbox:
            textbutton _(u"{font=gui/open-iconic.ttf}\uE021{/font}\nSave Game") action ShowMenu("save")
            textbutton _(u"{font=gui/open-iconic.ttf}\uE0AB{/font}\nQuit") action Quit()

init -2 python:
    style.mg_nav_button.size_group = "mg_nav"
    style.mg_nav_button.xpadding = 10
    style.mg_nav_button.ypadding = 10
    
##############################################################################
# Menu principal
#
# Écran utilisé pour le menu principal, quand Ren'Py démarre

screen menu_accueil:

    # Pour être sûr que tout autre menu est remplacé
    tag menu

    # Le fond du menu principal
    window:
        style "mm_root"

    # Les boutons du menu principal.
    frame:
        style_group "mm"
        xalign 0.95
        yalign 0.5
        background None

        has vbox

        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE069",style = "accueil_idle")
            if _preferences.language == None:
                hover Text("Read in\nEnglish", style = "accueil_hover")
                action Language("en")
            else:
                hover Text("Lire en\nfrançais", style = "accueil_hover")
                action Language(None)
        
        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE021",style = "accueil_idle")
            hover Text(_("Bookmark"), style = "accueil_hover")
            action ShowMenu("load")
        
        imagebutton:
            style "accueil_bouton"
            ysize 150
            xsize 200
            idle Text(u"\uE0A9",style = "accueil_idle", size = 80)
            hover Text(_("Read"), style = "accueil_hover" ,size = 50)
            action Start()
        
        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE041",style = "accueil_idle")
            hover Text(_("Options"), style = "accueil_hover")
            action ShowMenu("menu_options")
        
        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE0AB",style = "accueil_idle")
            hover Text(_("Quit"), style = "accueil_hover")
            action Quit(confirm=False)
            

init -2:
    # styles pour l'affichage des boutons de l'écran d'accueil
    style accueil_idle:
        font "gui/open-iconic.ttf"
        size 30
        #text_align 0.5
        color accueil_color
        outlines [(0,accueil_shadow,3,3),(1,accueil_shadow,0,0)]
        xalign 0.5
        yalign 0.5
    
    style accueil_hover is button_text:
        color accueil_color
        outlines [(0,accueil_shadow,2,2),(1,accueil_shadow,0,0)]
        text_align 0.5
        xalign 0.5
        yalign 0.5
        
    style accueil_bouton:
        xminimum 185
        ysize 110
        ymargin 20

        
##############################################################################
# Menu rapide perso
#
# Écran inclus par défaut pour les dialogues, ajoutant un accès rapide à 
# plusieurs fonctions utiles

#-----------------------------------------------------------------------------
# Definitions d'images pour les icones du menu rapide
define music = 0.0  # on initialise les variables qui vont servir à conserver la valeur des mixers
define son = 0.0    # sinon après il y aura des erreurs 

define quick_boutons = [
                {
                "image" : u"\uE092",
                "texte":_("Pause"),
                "action":Show("ecran_pause"),
                "nom":"pause"},
                
                {
                "image" : u"\uE0B0",
                "texte":_("Help"),
                "action":Help(),
                "nom":"aide"},
                
                {
                "image" : u"\uE093",
                "texte":_("Auto On"),
                "action":Preference("auto-forward", "toggle"),
                "nom":"avance_auto"},
                
                {
                "image" : u"\uE095",
                "texte":_("Back"),
                "action":Rollback(),
                "nom":"rollback"},
                
                {
                "image" : u"\uE041",
                "texte":_("Options"),
                "action":ShowMenu('menu_options'),
                "nom":"prefs"}
                ]

#-----------------------------------------------------------------------------
# Screen en lui-même
screen menu_rapide:

    # Ajoute un menu rapide au sein du jeu
    vbox:
        #style_group "quick"

        xalign 1.0
        yalign 1.0
        xoffset -4

        for i in range(len(quick_boutons)):
                imagebutton: 
                    yminimum 18
                    xalign 1.0
                    
                    idle Text(quick_boutons[i]["image"],style="quick_button_idle")
                    hover Text(quick_boutons[i]["texte"],style="quick_button_hover")
                    insensitive Text(quick_boutons[i]["image"],style="quick_button_insensitive")
                    
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_idle Text(u"\uE099",style="quick_button_selected")
                    else:
                        selected_idle Text(quick_boutons[i]["image"],style="quick_button_selected")
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_hover Text(u"Auto Off",style="quick_button_hover")
                    action quick_boutons[i]["action"]
                null height 5

init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    
    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12

    style.quick_button_image.set_parent('quick_button')
    style.quick_button_image.font="gui/open-iconic.ttf"
    style.quick_button_image.size=14
    
    style.quick_button_idle = Style(style.quick_button_image)
    style.quick_button_idle.color = "#ddd8"
    style.quick_button_idle.outlines = [(1,"#0008",1,1)]
    
    style.quick_button_hover = Style(style.quick_button_text)
    style.quick_button_hover.color = "#ddd8"
    style.quick_button_hover.outlines = [(1,"#0008",1,1)]

    style.quick_button_selected = Style(style.quick_button_image)
    style.quick_button_selected.color = "#3338"
    style.quick_button_selected.outlines = [(1,"#fff8",1,1)]

    style.quick_button_insensitive = Style(style.quick_button_image)
    style.quick_button_insensitive.color = "#7778"
    #style.quick_button_insensitive.outlines = [(1,"#fff",1,1)]